;                      http://tx4.us/nbs-iscc.htm
;                        NBS/ISCC Color System
;
;Copyright © 2003 Voluntocracy.  Permission is granted to copy and
;distribute modified or unmodified versions of this color dictionary
;provided the copyright notice and this permission notice are preserved
;on all copies and the entire such work is distributed under the terms
;of a permission notice identical to this one.
;
;"Pink" and "brown" are used instead of the more logical "pale red" and
;"dark orange".
;
;http://www.anthus.com/Colors/Cent.html by David A. Mundie, converted
;the NBS Centroid colors from Munsell to CIE XYZ, then converted to Mac
;QuickDraw RGB.  The colors were visibly biased towards pink and had
;duplications.
;
;John Foster reconverted supplied Munsell values via Munsell software
;downloaded from www.gretagmacbeth.com <http://www.gretagmacbeth.com>
;directly to RGB, and tried to resolve some duplicates.  Some of these
;don't even look right, because some of the bright colors are on the
;dark fringes with less chroma and are not centered and high up on the
;hue curves.  Many of the original Munsell values (noted) are outside
;the RGB gamut, and have been adjusted to the closest brightest RGB
;value by changing chroma until 0 or 255 is reached in one out of
;bounds RGB component.  Guesses were made in a few cases (noted) where
;the color was still illogical compared to the name.

;; Packaged for R7RS Scheme by Peter Lane, 2017

(define-library
  (slib nbs-iscc)
  (export nbs-iscc
          nbs-iscc-names
          )
  (import (scheme base)
          (scheme char)
          (slib color)
          (srfi 69))

  (begin

    ;; Given a colour name, return its colour
    (define (nbs-iscc colour-name)
      (hash-table-ref/default *nbs-iscc* (string-downcase colour-name) #f))

    ;; Return list of the available names
    (define (nbs-iscc-names)
      (hash-table-keys *nbs-iscc*))

    (define *nbs-iscc*
      (let ((ht (make-hash-table string=?)))
        (for-each (lambda (pair) (hash-table-set! ht (string-downcase (car pair)) (cdr pair)))
                  (list
                    (cons "Vivid Pink"		(xRGB->color #xFFB5BA))
                    (cons "Strong Pink"		(xRGB->color #xEA9399))
                    (cons "Deep Pink"		(xRGB->color #xE4717A))
                    (cons "Light Pink"		(xRGB->color #xF9CCCA))
                    (cons "Moderate Pink"	(xRGB->color #xDEA5A4))
                    (cons "Dark Pink"		(xRGB->color #xC08081))
                    (cons "Pale Pink"		(xRGB->color #xEAD8D7))
                    (cons "Grayish Pink"	(xRGB->color #xC4AEAD))
                    (cons "Pinkish White"	(xRGB->color #xEAE3E1))
                    (cons "Pinkish Gray"	(xRGB->color #xC1B6B3))
                    (cons "Vivid Red"		(xRGB->color #xBE0032))
                    (cons "Strong Red"		(xRGB->color #xBC3F4A))
                    (cons "Deep Red"		(xRGB->color #x841B2D))
                    (cons "Very Deep Red"	(xRGB->color #x5C0923))
                    (cons "Moderate Red"	(xRGB->color #xAB4E52))
                    (cons "Dark Red"		(xRGB->color #x722F37))
                    (cons "Very Dark Red"	(xRGB->color #x3F1728))
                    (cons "Light Grayish Red"	(xRGB->color #xAD8884))
                    (cons "Grayish Red"		(xRGB->color #x905D5D))
                    (cons "Dark Grayish Red"	(xRGB->color #x543D3F))
                    (cons "Blackish Red"	(xRGB->color #x2E1D21))
                    (cons "Reddish Gray"	(xRGB->color #x8F817F))
                    (cons "Dark Reddish Gray"	(xRGB->color #x5C504F))
                    (cons "Reddish Black"	(xRGB->color #x282022))
                    (cons "Vivid Yellowish Pink"  (xRGB->color #xFFB7A5))
                    (cons "Strong Yellowish Pink"	(xRGB->color #xF99379))
                    (cons "Deep Yellowish Pink"	(xRGB->color #xE66721))
                    (cons "Light Yellowish Pink"	(xRGB->color #xF4C2C2))
                    (cons "Moderate Yellowish Pink"	(xRGB->color #xD9A6A9))
                    (cons "Dark Yellowish Pink"	(xRGB->color #xC48379))
                    (cons "Pale Yellowish Pink"	(xRGB->color #xECD5C5))
                    (cons "Grayish Yellowish Pink"	(xRGB->color #xC7ADA3))
                    (cons "Brownish Pink"		(xRGB->color #xC2AC99))
                    (cons "Vivid Reddish Orange"	(xRGB->color #xE25822))
                    (cons "Strong Reddish Orange"	(xRGB->color #xD9603B))
                    (cons "Deep Reddish Orange"	(xRGB->color #xAA381E))
                    (cons "Moderate Reddish Orange"	(xRGB->color #xCB6D51))
                    (cons "Dark Reddish Orange"	(xRGB->color #x9E4732))
                    (cons "Grayish Reddish Orange"	(xRGB->color #xB4745E))
                    (cons "Strong Reddish Brown"	(xRGB->color #x882D17))
                    (cons "Deep Reddish Brown"	(xRGB->color #x56070C))
                    (cons "Light Reddish Brown"	(xRGB->color #xA87C6D))
                    (cons "Moderate Reddish Brown"	(xRGB->color #x79443B))
                    (cons "Dark Reddish Brown"	(xRGB->color #x3E1D1E))
                    (cons "Light Grayish Reddish Brown"	(xRGB->color #x977F73))
                    (cons "Grayish Reddish Brown"	(xRGB->color #x674C47))
                    (cons "Dark Grayish Reddish Brown"	(xRGB->color #x43302E))
                    (cons "Vivid Orange"		(xRGB->color #xF38400))
                    (cons "Brilliant Orange"	(xRGB->color #xFD943F))
                    (cons "Strong Orange"		(xRGB->color #xED872D))
                    (cons "Deep Orange"		(xRGB->color #xBE6516))
                    (cons "Light Orange"		(xRGB->color #xFAB57F))
                    (cons "Moderate Orange"		(xRGB->color #xD99058))
                    (cons "Brownish Orange"		(xRGB->color #xAE6938))
                    (cons "Strong Brown"		(xRGB->color #x80461B))
                    (cons "Deep Brown"		(xRGB->color #x593319))
                    (cons "Light Brown"		(xRGB->color #xA67B5B))
                    (cons "Moderate Brown"		(xRGB->color #x6F4E37))
                    (cons "Dark Brown"		(xRGB->color #x422518))
                    (cons "Light Grayish Brown"	(xRGB->color #x958070))
                    (cons "Grayish Brown"		(xRGB->color #x635147))
                    (cons "Dark Grayish Brown"	(xRGB->color #x3E322C))
                    (cons "Light Brownish Gray"	(xRGB->color #x8E8279))
                    (cons "Brownish Gray"		(xRGB->color #x5B504F))
                    (cons "Brownish Black"		(xRGB->color #x28201C))
                    (cons "Vivid Orange Yellow"	(xRGB->color #xF6A600))
                    (cons "Brilliant Orange Yellow"	(xRGB->color #xFFC14F))
                    (cons "Strong Orange Yellow"	(xRGB->color #xEAA221))
                    (cons "Deep Orange Yellow"	(xRGB->color #xC98500))
                    (cons "Light Orange Yellow"	(xRGB->color #xFBC97F))
                    (cons "Moderate Orange Yellow"	(xRGB->color #xE3A857))
                    (cons "Dark Orange Yellow"	(xRGB->color #xBE8A3D))
                    (cons "Pale Orange Yellow"	(xRGB->color #xFAD6A5))
                    (cons "Strong Yellowish Brown"	(xRGB->color #x996515))
                    (cons "Deep Yellowish Brown"	(xRGB->color #x654522))
                    (cons "Light Yellowish Brown"	(xRGB->color #xC19A6B))
                    (cons "Moderate Yellowish Brown"	(xRGB->color #x826644))
                    (cons "Dark Yellowish Brown"	(xRGB->color #x4B3621))
                    (cons "Light Grayish Yellowish Brown"	(xRGB->color #xAE9B82))
                    (cons "Grayish Yellowish Brown"	(xRGB->color #x7E6D5A))
                    (cons "Dark Grayish Yellowish Brown"	(xRGB->color #x483C32))
                    (cons "Vivid Yellow"		(xRGB->color #xF3C300))
                    (cons "Brilliant Yellow"	(xRGB->color #xFADA5E))
                    (cons "Strong Yellow"		(xRGB->color #xD4AF37))
                    (cons "Deep Yellow"		(xRGB->color #xAF8D13))
                    (cons "Light Yellow"		(xRGB->color #xF8DE7E))
                    (cons "Moderate Yellow"		(xRGB->color #xC9AE5D))
                    (cons "Dark Yellow"		(xRGB->color #xAB9144))
                    (cons "Pale Yellow"		(xRGB->color #xF3E5AB))
                    (cons "Grayish Yellow"		(xRGB->color #xC2B280))
                    (cons "Dark Grayish Yellow"	(xRGB->color #xA18F60))
                    (cons "Yellowish White"		(xRGB->color #xF0EAD6))
                    (cons "Yellowish Gray"		(xRGB->color #xBFB8A5))
                    (cons "Light Olive Brown"	(xRGB->color #x967117))
                    (cons "Moderate Olive Brown"	(xRGB->color #x6C541E))
                    (cons "Dark Olive Brown"	(xRGB->color #x3B3121))
                    (cons "Vivid Greenish Yellow"	(xRGB->color #xDCD300))
                    (cons "Brilliant Greenish Yellow"	(xRGB->color #xE9E450))
                    (cons "Strong Greenish Yellow"	(xRGB->color #xBEB72E))
                    (cons "Deep Greenish Yellow"	(xRGB->color #x9B9400))
                    (cons "Light Greenish Yellow"	(xRGB->color #xEAE679))
                    (cons "Moderate Greenish Yellow"	(xRGB->color #xB9B459))
                    (cons "Dark Greenish Yellow"	(xRGB->color #x98943E))
                    (cons "Pale Greenish Yellow"	(xRGB->color #xEBE8A4))
                    (cons "Grayish Greenish Yellow"	(xRGB->color #xB9B57D))
                    (cons "Light Olive"		(xRGB->color #x867E36))
                    (cons "Moderate Olive"		(xRGB->color #x665D1E))
                    (cons "Dark Olive"		(xRGB->color #x403D21))
                    (cons "Light Grayish Olive"	(xRGB->color #x8C8767))
                    (cons "Grayish Olive"		(xRGB->color #x5B5842))
                    (cons "Dark Grayish Olive"	(xRGB->color #x363527))
                    (cons "Light Olive Gray"	(xRGB->color #x8A8776))
                    (cons "Olive Gray"		(xRGB->color #x57554C))
                    (cons "Olive Black"		(xRGB->color #x25241D))
                    (cons "Vivid Yellow Green"	(xRGB->color #x8DB600))
                    (cons "Brilliant Yellow Green"	(xRGB->color #xBDDA57))
                    (cons "Strong Yellow Green"	(xRGB->color #x7E9F2E))
                    (cons "Deep Yellow Green"	(xRGB->color #x467129))
                    (cons "Light Yellow Green"	(xRGB->color #xC9DC89))
                    (cons "Moderate Yellow Green"	(xRGB->color #x8A9A5B))
                    (cons "Pale Yellow Green"	(xRGB->color #xDADFB7))
                    (cons "Grayish Yellow Green"	(xRGB->color #x8F9779))
                    (cons "Strong Olive Green"	(xRGB->color #x404F00))
                    (cons "Deep Olive Green"	(xRGB->color #x232F00))
                    (cons "Moderate Olive Green"	(xRGB->color #x4A5D23))
                    (cons "Dark Olive Green"	(xRGB->color #x2B3D26))
                    (cons "Grayish Olive Green"	(xRGB->color #x515744))
                    (cons "Dark Grayish Olive Green"	(xRGB->color #x31362B))
                    (cons "Vivid Yellowish Green"	(xRGB->color #x27A64C))
                    (cons "Brilliant Yellowish Green"	(xRGB->color #x83D37D))
                    (cons "Strong Yellowish Green"	(xRGB->color #x44944A))
                    (cons "Deep Yellowish Green"	(xRGB->color #x00622D))
                    (cons "Very Deep Yellowish Green"	(xRGB->color #x003118))
                    (cons "Very Light Yellowish Green"	(xRGB->color #xB6E5AF))
                    (cons "Light Yellowish Green"	(xRGB->color #x93C592))
                    (cons "Moderate Yellowish Green"	(xRGB->color #x679267))
                    (cons "Dark Yellowish Green"	(xRGB->color #x355E3B))
                    (cons "Very Dark Yellowish Green"	(xRGB->color #x173620))
                    (cons "Vivid Green"		(xRGB->color #x008856))
                    (cons "Brilliant Green"		(xRGB->color #x3EB489))
                    (cons "Strong Green"		(xRGB->color #x007959))
                    (cons "Deep Green"		(xRGB->color #x00543D))
                    (cons "Very Light Green"	(xRGB->color #x8ED1B2))
                    (cons "Light Green"		(xRGB->color #x6AAB8E))
                    (cons "Moderate Green"		(xRGB->color #x3B7861))
                    (cons "Dark Green"		(xRGB->color #x1B4D3E))
                    (cons "Very Dark Green"		(xRGB->color #x1C352D))
                    (cons "Very Pale Green"		(xRGB->color #xC7E6D7))
                    (cons "Pale Green"		(xRGB->color #x8DA399))
                    (cons "Grayish Green"		(xRGB->color #x5E716A))
                    (cons "Dark Grayish Green"	(xRGB->color #x3A4B47))
                    (cons "Blackish Green"		(xRGB->color #x1A2421))
                    (cons "Greenish White"		(xRGB->color #xDFEDE8))
                    (cons "Light Greenish Gray"	(xRGB->color #xB2BEB5))
                    (cons "Greenish Gray"		(xRGB->color #x7D8984))
                    (cons "Dark Greenish Gray"	(xRGB->color #x4E5755))
                    (cons "Greenish Black"		(xRGB->color #x1E2321))
                    (cons "Vivid Bluish Green"	(xRGB->color #x008882))
                    (cons "Brilliant Bluish Green"	(xRGB->color #x00A693))
                    (cons "Strong Bluish Green"	(xRGB->color #x007A74))
                    (cons "Deep Bluish Green"	(xRGB->color #x00443F))
                    (cons "Very Light Bluish Green"	(xRGB->color #x96DED1))
                    (cons "Light Bluish Green"	(xRGB->color #x66ADA4))
                    (cons "Moderate Bluish Green"	(xRGB->color #x317873))
                    (cons "Dark Bluish Green"	(xRGB->color #x004B49))
                    (cons "Very Dark Bluish Green"	(xRGB->color #x002A29))
                    (cons "Vivid Greenish Blue"	(xRGB->color #x0085A1))
                    (cons "Brilliant Greenish Blue"	(xRGB->color #x239EBA))
                    (cons "Strong Greenish Blue"	(xRGB->color #x007791))
                    (cons "Deep Greenish Blue"	(xRGB->color #x2E8495))
                    (cons "Very Light Greenish Blue"	(xRGB->color #x9CD1DC))
                    (cons "Light Greenish Blue"	(xRGB->color #x66AABC))
                    (cons "Moderate Greenish Blue"	(xRGB->color #x367588))
                    (cons "Dark Greenish Blue"	(xRGB->color #x004958))
                    (cons "Very Dark Greenish Blue"	(xRGB->color #x002E3B))
                    (cons "Vivid Blue"		(xRGB->color #x00A1C2))
                    (cons "Brilliant Blue"		(xRGB->color #x4997D0))
                    (cons "Strong Blue"		(xRGB->color #x0067A5))
                    (cons "Deep Blue"		(xRGB->color #x00416A))
                    (cons "Very Light Blue"		(xRGB->color #xA1CAF1))
                    (cons "Light Blue"		(xRGB->color #x70A3CC))
                    (cons "Moderate Blue"		(xRGB->color #x436B95))
                    (cons "Dark Blue"		(xRGB->color #x00304E))
                    (cons "Very Pale Blue"		(xRGB->color #xBCD4E6))
                    (cons "Pale Blue"		(xRGB->color #x91A3B0))
                    (cons "Grayish Blue"		(xRGB->color #x536878))
                    (cons "Dark Grayish Blue"	(xRGB->color #x36454F))
                    (cons "Blackish Blue"		(xRGB->color #x202830))
                    (cons "Bluish White"		(xRGB->color #xE9E9ED))
                    (cons "Light Bluish Gray"	(xRGB->color #xB4BCC0))
                    (cons "Bluish Gray"		(xRGB->color #x81878B))
                    (cons "Dark Bluish Gray"	(xRGB->color #x51585E))
                    (cons "Bluish Black"		(xRGB->color #x202428))
                    (cons "Vivid Purplish Blue"	(xRGB->color #x30267A))
                    (cons "Brilliant Purplish Blue"	(xRGB->color #x6C79B8))
                    (cons "Strong Purplish Blue"	(xRGB->color #x545AA7))
                    (cons "Deep Purplish Blue"	(xRGB->color #x272458))
                    (cons "Very Light Purplish Blue"  (xRGB->color #xB3BCE2))
                    (cons "Light Purplish Blue"	(xRGB->color #x8791BF))
                    (cons "Moderate Purplish Blue"	(xRGB->color #x4E5180))
                    (cons "Dark Purplish Blue"	(xRGB->color #x252440))
                    (cons "Very Pale Purplish Blue"	(xRGB->color #xC0C8E1))
                    (cons "Pale Purplish Blue"	(xRGB->color #x8C92AC))
                    (cons "Grayish Purplish Blue"	(xRGB->color #x4C516D))
                    (cons "Vivid Violet"		(xRGB->color #x9065CA))
                    (cons "Brilliant Violet"	(xRGB->color #x7E73B8))
                    (cons "Strong Violet"		(xRGB->color #x604E97))
                    (cons "Deep Violet"		(xRGB->color #x32174D))
                    (cons "Very Light Violet"	(xRGB->color #xDCD0FF))
                    (cons "Light Violet"		(xRGB->color #x8C82B6))
                    (cons "Moderate Violet"		(xRGB->color #x604E81))
                    (cons "Dark Violet"		(xRGB->color #x2F2140))
                    (cons "Very Pale Violet"	(xRGB->color #xC4C3DD))
                    (cons "Pale Violet"		(xRGB->color #x9690AB))
                    (cons "Grayish Violet"		(xRGB->color #x554C69))
                    (cons "Vivid Purple"		(xRGB->color #x9A4EAE))
                    (cons "Brilliant Purple"	(xRGB->color #xD399E6))
                    (cons "Strong Purple"		(xRGB->color #x875692))
                    (cons "Deep Purple"		(xRGB->color #x602F6B))
                    (cons "Very Deep Purple"	(xRGB->color #x401A4C))
                    (cons "Very Light Purple"	(xRGB->color #xD5BADB))
                    (cons "Light Purple"		(xRGB->color #xB695C0))
                    (cons "Moderate Purple"		(xRGB->color #x86608E))
                    (cons "Dark Purple"		(xRGB->color #x563C5C))
                    (cons "Very Dark Purple"	(xRGB->color #x301934))
                    (cons "Very Pale Purple"	(xRGB->color #xD6CADD))
                    (cons "Pale Purple"		(xRGB->color #xAA98A9))
                    (cons "Grayish Purple"		(xRGB->color #x796878))
                    (cons "Dark Grayish Purple"	(xRGB->color #x50404D))
                    (cons "Blackish Purple"		(xRGB->color #x291E29))
                    (cons "Purplish White"		(xRGB->color #xE8E3E5))
                    (cons "Light Purplish Gray"	(xRGB->color #xBFB9BD))
                    (cons "Purplish Gray"		(xRGB->color #x8B8589))
                    (cons "Dark Purplish Gray"	(xRGB->color #x5D555B))
                    (cons "Purplish Black"		(xRGB->color #x242124))
                    (cons "Vivid Reddish Purple"	(xRGB->color #x870074))
                    (cons "Strong Reddish Purple"	(xRGB->color #x9E4F88))
                    (cons "Deep Reddish Purple"	(xRGB->color #x702963))
                    (cons "Very Deep Reddish Purple"	(xRGB->color #x54194E))
                    (cons "Light Reddish Purple"	(xRGB->color #xB784A7))
                    (cons "Moderate Reddish Purple"	(xRGB->color #x915C83))
                    (cons "Dark Reddish Purple"	(xRGB->color #x5D3954))
                    (cons "Very Dark Reddish Purple"	(xRGB->color #x341731))
                    (cons "Pale Reddish Purple"	(xRGB->color #xAA8A9E))
                    (cons "Grayish Reddish Purple"	(xRGB->color #x836479))
                    (cons "Brilliant Purplish Pink"	(xRGB->color #xFFC8D6))
                    (cons "Strong Purplish Pink"	(xRGB->color #xE68FAC))
                    (cons "Deep Purplish Pink"	(xRGB->color #xDE6FA1))
                    (cons "Light Purplish Pink"	(xRGB->color #xEFBBCC))
                    (cons "Moderate Purplish Pink"	(xRGB->color #xD597AE))
                    (cons "Dark Purplish Pink"	(xRGB->color #xC17E91))
                    (cons "Pale Purplish Pink"	(xRGB->color #xE8CCD7))
                    (cons "Grayish Purplish Pink"	(xRGB->color #xC3A6B1))
                    (cons "Vivid Purplish Red"	(xRGB->color #xCE4676))
                    (cons "Strong Purplish Red"	(xRGB->color #xB3446C))
                    (cons "Deep Purplish Red"	(xRGB->color #x78184A))
                    (cons "Very Deep Purplish Red"	(xRGB->color #x54133B))
                    (cons "Moderate Purplish Red"	(xRGB->color #xA8516E))
                    (cons "Dark Purplish Red"	(xRGB->color #x673147))
                    (cons "Very Dark Purplish Red"	(xRGB->color #x38152C))
                    (cons "Light Grayish Purplish Red"	(xRGB->color #xAF868E))
                    (cons "Grayish Purplish Red"	(xRGB->color #x915F6D))
                    (cons "White"			(xRGB->color #xF2F3F4))
                    (cons "Light Gray"		(xRGB->color #xB9B8B5))
                    (cons "Medium Gray"		(xRGB->color #x848482))
                    (cons "Dark Gray"		(xRGB->color #x555555))
                    (cons "Black"			(xRGB->color #x222222))
                    ))
        ht))

    ))

